Builds, installs and loads the package. In addition the source package is saved in the directory with the files for the Docker image.
build_and_install_package(pkg = ".", dir_source_packages,
pkgname_pkgversion, verbose = FALSE, ...)Path to a package, or within a package.
character directory containing the
specific local source packages, that will be included in the Docker container
image.
character the package name concatenated
with the version number of the package.
logical should messages be printed or not?
optional arguments for install packages.
invisibly. The package is built, installed and loaded as side effects. Furthermore the source package is saved in the folder containing the files for the Docker image.