Copy Local Source Packages to Docker Subdirectory
copy_local_pkgs(pkgs_df = NULL, dir_src = NULL,
dir_src_docker = NULL, verbose = TRUE)data.frame with names and version numbers of packages
to be copied to Docker subdirectory.
character directories with local source packages.
Note, the source packages must have filenames like
(packageName)_(packageVersion).tar.gz, e.g. "recorder_0.8.2.tar.gz".
Put directories in prioritized order. The first directory will have the
highest priority.
character subdirectory of Docker image
directory with relevant source packages, that will be installed in the Docker
container. Relevant local source packages will be copied to this directory.
logical should messages be printed or not?
invisibly. As a side effect source package files (*.tar.gz) are copied to Docker subdirectory.