Mirrors version numbers of specific packages. If a package is loaded, the version number of the loaded package is used. If a packages is not loaded but installed, the version number of the installed package will be extracted in stead.
mirror_package_versions(pkgs)character names of packages.
data.frame with package names and their relevant version
numbers.